@@ -1,4 +1,7 @@
 from .enum import enum_type  # noqa
+from .execute import ExecutionContext  # noqa
+from .middleware import MiddlewareManager  # noqa
+from .parser import parse_info, FieldMeta, parse_node  # noqa
 from .resolver import (  # noqa
     field_resolver,
     mutate,
@@ -8,6 +11,8 @@ from .resolver import (  # noqa
     type_resolver,
 )
 from .scalar import scalar_type  # noqa
-from .schema import make_schema, make_schema_from_file  # noqa
+from .schema import make_schema, make_schema_from_file, make_schema_from_path  # noqa
 from .schema_visitor import SchemaDirectiveVisitor  # noqa
 from .utils import gql  # noqa
+
+__version__ = '0.2.3'
